@@ -1,10 +1,13 @@
-from prompt_toolkit.enums import DEFAULT_BUFFER
-from prompt_toolkit.filters import Condition
+from __future__ import annotations
+
 from prompt_toolkit.application import get_app
-from .packages import special
+from prompt_toolkit.enums import DEFAULT_BUFFER
+from prompt_toolkit.filters import Condition, Filter
+
+from mycli.packages.special import iocommands
 
 
-def cli_is_multiline(mycli):
+def cli_is_multiline(mycli) -> Filter:
     @Condition
     def cond():
         doc = get_app().layout.get_buffer_by_name(DEFAULT_BUFFER).document
@@ -17,7 +20,7 @@ def cli_is_multiline(mycli):
     return cond
 
 
-def _multiline_exception(text):
+def _multiline_exception(text: str) -> bool:
     orig = text
     text = text.strip()
 
@@ -36,7 +39,7 @@ def _multiline_exception(text):
         or
         # Ended with the current delimiter (usually a semi-column)
         text.endswith((
-            special.get_current_delimiter(),
+            iocommands.get_current_delimiter(),
             "\\g",
             "\\G",
             r"\e",
